<?php

// Connect to the database (adjust credentials as needed)
$conn = new mysqli('localhost', 'trivenzo_rizwan', 'GmFCt80r1Igs', 'trivenzo_all_data_managment');

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Initialize variables
$search = isset($_POST['search']) ? $_POST['search'] : '';
$item_status_filter = isset($_POST['item_status']) ? $_POST['item_status'] : '';
$item_category_filter = isset($_POST['item_category']) ? $_POST['item_category'] : '';
$min_price = isset($_POST['min_price']) ? $_POST['min_price'] : '';
$max_price = isset($_POST['max_price']) ? $_POST['max_price'] : '';

// Base SQL query
$sql = "SELECT items_id, item_name, item_desc, item_price, item_quantity, item_status, item_image_url, item_catagories FROM items WHERE item_name LIKE ?";
$search_param = "%" . $search . "%";

// Add filters to SQL query
if ($item_status_filter != '') {
    $sql .= " AND item_status = ?";
}

if ($item_category_filter != '') {
    $sql .= " AND item_catagories = ?";
}

if ($min_price !== '' && $max_price !== '') {
    $sql .= " AND item_price BETWEEN ? AND ?";
} elseif ($min_price !== '') {
    $sql .= " AND item_price >= ?";
} elseif ($max_price !== '') {
    $sql .= " AND item_price <= ?";
}

$stmt = $conn->prepare($sql);

// Bind parameters
$params = [$search_param];

if ($item_status_filter != '') {
    $params[] = $item_status_filter;
}

if ($item_category_filter != '') {
    $params[] = $item_category_filter;
}

if ($min_price !== '' && $max_price !== '') {
    $params[] = $min_price;
    $params[] = $max_price;
} elseif ($min_price !== '') {
    $params[] = $min_price;
} elseif ($max_price !== '') {
    $params[] = $max_price;
}

$stmt->bind_param(str_repeat("s", count($params)), ...$params);

$stmt->execute();
$result = $stmt->get_result();

$total_products = $result->num_rows; // Count total products

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Product List</title>
    <style>
        table {
            width: 100%;
            border-collapse: collapse;
        }
        th, td {
            border: 1px solid #000;
            padding: 10px;
            text-align: left;
        }
        img {
            width: 100px;
        }
        input[type="text"], select {
            margin-bottom: 20px;
            padding: 10px;
            width: 300px;
        }
    </style>
</head>
<body>

<h2>Product List</h2>

<form method="post">
    <input type="text" name="search" placeholder="Search by item name..." value="<?php echo htmlspecialchars($search); ?>">
    
    <select name="item_status">
        <option value="">Select Status</option>
        <option value="available" <?php echo ($item_status_filter == 'available') ? 'selected' : ''; ?>>Available</option>
        <option value="out of stock" <?php echo ($item_status_filter == 'out of stock') ? 'selected' : ''; ?>>Out of Stock</option>
        <option value="not available" <?php echo ($item_status_filter == 'not available') ? 'selected' : ''; ?>>Not Available</option>
    </select>
    
   <select name="item_category">
    <option value="">Select Category</option>
    <option value="burgers" <?php echo ($item_category_filter == 'burgers') ? 'selected' : ''; ?>>Burgers</option>
    <option value="fries" <?php echo ($item_category_filter == 'fries') ? 'selected' : ''; ?>>Fries</option>
    <option value="wrap" <?php echo ($item_category_filter == 'wrap') ? 'selected' : ''; ?>>Wrap</option>
    <option value="juice" <?php echo ($item_category_filter == 'juice') ? 'selected' : ''; ?>>Juice</option>
    <option value="meat" <?php echo ($item_category_filter == 'meat') ? 'selected' : ''; ?>>Meat</option>
    <option value="icecream" <?php echo ($item_category_filter == 'icecream') ? 'selected' : ''; ?>>Icecream</option>
    <option value="dessert" <?php echo ($item_category_filter == 'dessert') ? 'selected' : ''; ?>>Dessert</option>
    <option value="barbecue" <?php echo ($item_category_filter == 'barbecue') ? 'selected' : ''; ?>>barbecue</option>
</select>

    <input type="text" name="min_price" placeholder="Min Price" value="<?php echo htmlspecialchars($min_price); ?>">
    <input type="text" name="max_price" placeholder="Max Price" value="<?php echo htmlspecialchars($max_price); ?>">
    
    <input type="submit" value="Filter">
</form>

<?php
// Display total products found
echo "<p>Total Products Found: {$total_products}</p>";

if ($total_products > 0) {
    echo "<table>";
    echo "<tr>
            <th>Item ID</th>
            <th>Item Name</th>
            <th>Item Description</th>
            <th>Item Price</th>
            <th>Item Quantity</th>
            <th>Item Status</th>
            <th>Item Image</th>
            <th>Item Category</th>
          </tr>";

    // Output data of each row
    while ($row = $result->fetch_assoc()) {
        echo "<tr>
                <td>{$row['items_id']}</td>
                <td>{$row['item_name']}</td>
                <td>{$row['item_desc']}</td>
                <td>{$row['item_price']}</td>
                <td>{$row['item_quantity']}</td>
                <td>{$row['item_status']}</td>
                <td><img src='{$row['item_image_url']}' alt='{$row['item_name']}'></td>
                <td>{$row['item_catagories']}</td>
              </tr>";
    }
    echo "</table>";
} else {
    echo "No products found.";
}

$stmt->close();
$conn->close();
?>

</body>
</html>
