document.addEventListener('DOMContentLoaded', async () => {
    const menuCardContainer = document.getElementById('menu-card-container');
    const loadMoreBtn = document.getElementById('load-more-btn');
    const itemsPerPage = 8;
    let currentPage = 1;
    let currentCategory = 'burgers'; // Set the default category to 'burgers'

    async function fetchMenuItems(category) {
        try {
            const response = await fetch(`/lexo/frontend/home/assets/data/product/${category}.json`);
            if (!response.ok) {
                throw new Error('Failed to fetch data');
            }
            const data = await response.json();
            return data;
        } catch (error) {
            console.error('Error fetching menu items:', error);
            return [];
        }
    }

    function createCard(item) {
        const card = document.createElement('div');
        card.classList.add('card');
        card.innerHTML = `
            <img src="${item.img}" alt="${item.name}">
            <h1>${item.name}</h1>
            <p>${item.description}</p>
            <div class="sub-1">
                <span>Price: </span>
                <span style="font-size: 2rem; font-weight:600;">$${item.price}</span>
            </div>
            <button class="myclass">Buy</button>
        `;
        return card;
    }

    function displayItems(items, page) {
        const start = (page - 1) * itemsPerPage;
        const end = start + itemsPerPage;
        const itemsToDisplay = items.slice(start, end);
        itemsToDisplay.forEach(item => {
            const card = createCard(item);
            menuCardContainer.appendChild(card);
        });

        // Show or hide the load more button
        if (end >= items.length) {
            loadMoreBtn.style.display = 'none';
        } else {
            loadMoreBtn.style.display = 'block';
        }
    }

    async function loadCategory(category) {
        currentCategory = category;
        currentPage = 1;
        menuCardContainer.innerHTML = ''; // Clear previous items
        const items = await fetchMenuItems(category);
        displayItems(items, currentPage);
    }

    loadMoreBtn.addEventListener('click', async () => {
        const items = await fetchMenuItems(currentCategory);
        displayItems(items, ++currentPage);
    });

    // Add event listeners to category links
    const categoryLinks = document.querySelectorAll('#menu-list a');
    categoryLinks.forEach(link => {
        link.addEventListener('click', async (event) => {
            event.preventDefault(); // Prevent default anchor behavior
            const category = event.target.id; // Get the clicked category id
            await loadCategory(category); // Load the selected category
        });
    });

    // Load the default category (Burger) when the page loads
    await loadCategory(currentCategory);
});

