document.getElementById('locate').addEventListener('click', function () {
    if (navigator.geolocation) {
        navigator.geolocation.getCurrentPosition(showPosition, showError);
    } else {
        document.getElementById('locationResult').innerHTML = "Geolocation is not supported by this browser.";
    }
});

function showPosition(position) {
    const latitude = position.coords.latitude;
    const longitude = position.coords.longitude;

    // Use OpenStreetMap's Nominatim service for reverse geocoding
    const geocodeUrl = `https://nominatim.openstreetmap.org/reverse?format=json&lat=${latitude}&lon=${longitude}`;

    fetch(geocodeUrl)
        .then(response => response.json())
        .then(data => {
            const address = data.display_name;
            document.getElementById('search').value = address;
            document.getElementById('locationResult').innerHTML = `You are located at : ${address}`;
        })
        .catch(error => {
            console.error('Error:', error);
            document.getElementById('locationResult').innerHTML = "An error occurred while retrieving the address.";
        });
}

function showError(error) {
    switch (error.code) {
        case error.PERMISSION_DENIED:
            document.getElementById('locationResult').innerHTML = "Please allow your location for our orders";
            break;
        case error.POSITION_UNAVAILABLE:
            document.getElementById('locationResult').innerHTML = "Location information is unavailable.";
            break;
        case error.TIMEOUT:
            document.getElementById('locationResult').innerHTML = "The request to get user location timed out.";
            break;
        case error.UNKNOWN_ERROR:
            document.getElementById('locationResult').innerHTML = "An unknown error occurred.";
            break;
    }
}