<?php
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Database connection
    $conn = new mysqli('localhost', 'trivenzo_rizwan', 'GmFCt80r1Igs', 'trivenzo_all_data_managment');
    if ($conn->connect_error) {
        die("Connection failed: " . $conn->connect_error);
    }

    // Input sanitization and validation
    $username = trim($_POST['username'] ?? '');
    $email = filter_var($_POST['email'], FILTER_SANITIZE_EMAIL) ?? '';
    $gender = trim($_POST['gender'] ?? '');
    $password = trim($_POST['password'] ?? '');
    $number = trim($_POST['number'] ?? '');
    $address = trim($_POST['address'] ?? '');
    $avatar_image = $_FILES['avatar']['name'] ?? '';

    if (empty($username) || empty($email) || empty($gender) || empty($password) || empty($number) || empty($address) || empty($avatar_image)) {
        die("All fields are required.");
    }

    // Validate email
    if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        die("Invalid email format.");
    }

    // Validate image (check file type)
    $allowed_extensions = ['jpg', 'jpeg', 'png', 'gif'];
    $file_extension = pathinfo($avatar_image, PATHINFO_EXTENSION);
    
    if (!in_array(strtolower($file_extension), $allowed_extensions)) {
        die("Invalid image format. Only JPG, JPEG, PNG, and GIF files are allowed.");
    }

    // Generate a unique user_id
    $user_id = rand(100000, 999999);
    $hashed_password = password_hash($password, PASSWORD_DEFAULT);

    // Handle image upload
    $target_dir = "frontend/home/assets/images/avatars/";
    $target_file = $target_dir . basename($avatar_image);

    if (!is_dir($target_dir)) {
        mkdir($target_dir, 0755, true);
    }

    if (move_uploaded_file($_FILES['avatar']['tmp_name'], $target_file)) {
        // Prepare SQL query
        $sql = "INSERT INTO users (user_id, username, email, gender, password, number, address, avatar_image) VALUES (?, ?, ?, ?, ?, ?, ?, ?)";
        $stmt = $conn->prepare($sql);
        if ($stmt === false) {
            die("Error preparing the statement: " . $conn->error);
        }

        // Bind parameters and execute statement
        $stmt->bind_param("isssssss", $user_id, $username, $email, $gender, $hashed_password, $number, $address, $target_file);

        if ($stmt->execute()) {
            echo "Account created successfully.";
        } else {
            echo "Error executing query: " . $stmt->error;
        }

        $stmt->close();
    } else {
        echo "Error uploading image.";
    }

    $conn->close();
}
?>


<!-- The rest of your HTML remains the same -->

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Item Form</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css">
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f4f4f4;
            margin: 0;
            padding: 20px;
        }
        .container {
            max-width: 600px;
            margin: auto;
            background: white;
            padding: 20px;
            border-radius: 5px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }
        h2 {
            text-align: center;
            color: #333;
        }
        label {
            display: block;
            margin: 10px 0 5px;
            font-weight: bold;
        }
        input[type="text"], textarea, select {
            width: 100%;
            padding: 10px;
            margin-bottom: 20px;
            border: 1px solid #ccc;
            border-radius: 4px;
        }
        input[type="file"] {
            margin-bottom: 20px;
        }
        input[type="submit"] {
            background-color: #28a745;
            color: white;
            padding: 10px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 16px;
            width: 100%;
        }
        input[type="submit"]:hover {
            background-color: #218838;
        }
        .popup {
            display: none;
            position: fixed;
            left: 50%;
            top: 50%;
            transform: translate(-50%, -50%);
            background-color: white;
            padding: 20px;
            border-radius: 5px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.2);
            z-index: 1000;
        }
        .popup.active {
            display: block;
        }
        .close-btn {
            cursor: pointer;
            color: #28a745;
            margin-top: 10px;
        }
    </style>
</head>
<body>
    <div class="container">
        <h2>Add Item</h2>
        <form action="" method="post" enctype="multipart/form-data">
            <label for="item_name">Item Name:</label>
            <input type="text" name="item_name" required>

            <label for="item_desc">Item Description:</label>
            <textarea name="item_desc" required></textarea>

            <label for="item_price">Item Price:</label>
            <input type="text" name="item_price" required>

            <label for="item_quantity">Item Quantity:</label>
            <input type="text" name="item_quantity" required>

            <label for="item_status">Item Status:</label>
            <select name="item_status" required>
                <option value="available">Available</option>
                <option value="out of stock">Out of Stock</option>
                <option value="not available">Not Available</option>
            </select>

            <label for="item_image">Item Image:</label>
            <input type="file" name="item_image" accept="image/*" required>

          <label for="item_category">Item Category:</label>
<select name="item_category" required>
    <option value="burgers">Burgers</option>
    <option value="fries">Fries</option>
    <option value="wrap">Wrap</option>
    <option value="juice">Juice</option>
    <option value="meat">Meat</option>
    <option value="Icecream">Icecream</option>
    <option value="desserts">Desserts</option>
    <option value="barbecue">Barbecue</option>
</select>


            <input type="submit" value="Save">
        </form>
    </div>

    <?php if ($success_message): ?>
        <div class="popup active" id="popup">
            <p><?php echo $success_message; ?></p>
            <span class="close-btn" onclick="closePopup()">Close</span>
        </div>
    <?php endif; ?>

    <script>
        function closePopup() {
            document.getElementById('popup').classList.remove('active');
        }

        // Automatically close the popup after 3 seconds
        setTimeout(() => {
            closePopup();
        }, 3000);
    </script>
</body>
</html>
